import Link from "next/link";
import Image from "next/image";
import axios from "axios";
import { useEffect, useState } from "react";
import {
  successMessage,
  errorMessage,
  dataErrorsMessage,
  catchMessage,
  successStoreMessage,
} from "../utiliz/showMessage";

const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

export default function AcademicStaff() {
  const [title, setTitle] = useState();
  const [picture, setPicture] = useState();
  const [education, setEducation] = useState();
  const [description, setDiscription] = useState();
  const [selectedImage, setSelectedImage] = useState();

  const clearForm = () => {
    try {
      setTitle("");
      setPicture("");
      setEducation("");
      setDiscription("");
      //   setReload(new Date());
    } catch (error) {
      throw error;
    }
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        title: Joi.string().required().min(3).max(256).messages({
          "string.min": `"  نام و نام خانوادگی" حداقل {#limit} حرف وارد شود  `,
          "string.max": `"نام و نام خانوادگی" حداکثر {#limit} حرف وارد شود  `,
          "any.required": `"نام و نام خانوادگی" وارد شود`,
        }),

        education: Joi.string().required().min(4).max(256).messages({
          "string.min": `" تحصیلات  " حداقل{#limit}  حرف وارد شود  `,
          "string.max": `"   تحصیلات" حداکثر {#limit}حرف وارد شود  `,
          "any.required": `" تحصیلات  " وارد شود`,
        }),

        description: Joi.string().required().min(10).max(256).messages({
          "string.min": `" توضیحات  " حداقل{#limit}  حرف وارد شود  `,
          "string.max": `" توضیحات  " حداکثر {#limit} حرف وارد شود  `,
          "any.required": `"   توضیحات" وارد شود`,
        }),
      });
      const { error } = schema.validate({
        title: title,

        education: education,
        description: description,
      });
      if (error) {
        errorMessage(error.details[0].message);
        // console.log(error)
        return false;
      }
      return true;
    } catch (error) {
      console.log("------------", error);

      setLoading(false);
      catchMessage(error);
      return false;
    }
  };
  const imageChangeHandler = (e) => {
    setPicture(e.target.files[0]);
  };
  const handleSubmitClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("title", title);
      formData.append("education", education);
      formData.append("description", description);
      formData.append("picture", picture);

      await axios
        .post("/api/academic/store", formData, {
          headers: {
            "Content-Type": "multipart/formdata",
          },
        })
        .then((result) => {
          console.log("result", result);
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (error) {
      console.log(error);
    }
    successStoreMessage();
    clearForm();
  };
  useEffect(() => {}, []);
  return (
    <div>
      <section className="contact__area grey-bg-13 pt-120 pb-120">
        <div className="container">
          <div className="row">
            <div className="col-xxl-12 col-xl-12 col-lg-12">
              <div className="contact__form contact__form-2 white-bg">
                <h3 className="contact-form-title">لطفا مشخصات خود را وارد کنید</h3>
                <form>
                  <div className="row">
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>نام و نام خانوادگی</label>
                        <input
                          type="text"
                          value={title}
                          onChange={(e) => {
                            setTitle(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>تحصیلات</label>
                        <input
                          type="text"
                          name="education"
                          id="education"
                          value={education}
                          onChange={(e) => {
                            setEducation(e.target.value);
                          }}
                        />
                      </div>
                    </div>
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>توضیحات کوتاه</label>
                        <textarea
                          id="w3review"
                          name="w3review"
                          rows="4"
                          cols="50"
                          value={description}
                          onChange={(e) => {
                            setDiscription(e.target.value);
                          }}
                        />
                      </div>
                    </div>
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className=" contact__input contact__input-2 mb-30">
                        <label>برای اپلود عکس خود اینجا کلیک کنید</label>
                        <input
                          accept="image/*"
                          name="file"
                          id="filer_input2"
                          type="file"
                          onChange={imageChangeHandler}
                        />
                      </div>
                    </div>
                    <div className="col-xl-12">
                      <div className="contact__form-btn-2">
                        <button
                          style={{ float: "left" }}
                          type="button"
                          onClick={() => {
                            handleSubmitClick();
                          }}
                        >
                          <span className="d-flex align-items-center">ثبت</span>
                        </button>
                      </div>
                    </div>
                  </div>
                </form>
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  );
}
