import Link from "next/link";
import Image from "next/image";
import axios from "axios";
import { useEffect, useState } from "react";
import {
  successMessage,
  errorMessage,
  dataErrorsMessage,
  catchMessage,
  successStoreMessage,
} from "../utiliz/showMessage";
import {
  setLogin,
  setStartLogin,
  useLiTechController,
  setLoading,
} from "@/utils/context";

const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

export default function LoginComponent(props) {
  const [controller, dispatch] = useLiTechController();
  const { handleCloseLogin, handleClose } = props;
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");

  const clearForm = () => {
    try {
      setUsername("");
      setPassword("");
    } catch (error) {
      throw error;
    }
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        username: Joi.string().messages({
          "any.required": `"نام کاربری" وارد شود`,
          "string.empty": `"نام کاربری" وارد شود`,
        }),
        password: Joi.string().required().messages({
          "any.required": `"رمز عبور " وارد شود`,
          "string.empty": `"رمز عبور " وارد شود`,
        }),
      });
      const { error } = schema.validate({
        username: username,
        password: password,
      });
      if (error) {
        errorMessage(error.details[0].message);

        return false;
      }
      return true;
    } catch (error) {
      console.log("------------", error);

      setLoading(false);
      catchMessage(error);
      return false;
    }
  };

  const handleSubmitClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = {
        username,
        password,
      };
      await axios
        .post("/api/auth/login", formData)
        .then((result) => {
          if (result.data.success) {
            console.log("jufhvker", result.data.data);
            setLogin(dispatch, result.data.data);
            setStartLogin(dispatch, false);
            clearForm();
          } else {
            errorMessage(result.data.message);
          }
        })
        .catch((err) => {
          console.log("----err-", err);
          errorMessage(result.data.message);
        });
    } catch (error) {
      console.log(error);
    }
  };

  useEffect(() => {}, []);
  return (
    <div>
      <div className="row">
        <div className="col-xxl-12 col-xl-12 col-lg-12">
          <div className="contact__form contact__form-2 white-bg">
            <form>
              <div className="row">
                <div className=" col-12">
                  <div className="contact__input contact__input-2 mb-30">
                    <label>user name</label>
                    <input
                      type="text"
                      value={username}
                      onChange={(e) => {
                        setUsername(e.target.value);
                      }}
                    />
                  </div>
                </div>

                <div className=" col-12">
                  <div className="contact__input contact__input-2 mb-30">
                    <label>password</label>
                    <input
                      type="password"
                      value={password}
                      security=""
                      onChange={(e) => {
                        setPassword(e.target.value);
                      }}
                    />
                  </div>
                </div>

                <div className="col-xl-12">
                  <div className="contact__form-btn-2">
                    <button
                      style={{ float: "left" }}
                      type="button"
                      onClick={() => {
                        handleSubmitClick();
                      }}
                    >
                      <span className="d-flex align-items-center">ورود</span>
                    </button>

                    <div
                  
                      style={{ float: "right" }}
                      type="button"
                      onClick={() => {
                        setStartLogin(dispatch, false);
                      }}
                    >
                      <span
                        style={{ paddingTop: 10 }}
                        className="d-flex align-items-center"
                      >
                      
                        حساب کاربری ندارید؟
                        <Link
                          style={{ color: "blue" }}
                          href="/registeruserforadmin"
                        >
                          
                          ایجاد حساب کاربری
                        </Link>
                      </span>
                    </div>

                  </div>
                </div>
              </div>
            </form>
          </div>
        </div>
      </div>
    </div>
  );
}
