import { setLogout, setStartLogin, useLiTechController } from "@/utils/context";
import Link from "next/link";
import { useEffect, useState } from "react";
import { Button, Container, Nav, Navbar, NavDropdown } from "react-bootstrap";

export default function NavbarComponenet() {
  const [controller, dispatch] = useLiTechController();
  const [loginText, setLoginText] = useState("ورود");
  useEffect(() => {
    setLoginText(controller.authenticated ? "خروج" : "ورود/ثبت نام");
  }, [controller.authenticated]);
  return (
    <>
      {controller.loading && (
        <div id="loading">
          <div id="loading-center">
            <div id="loading-center-absolute">
              <div className="object" id="object_one"></div>
              <div className="object" id="object_two"></div>
              <div className="object" id="object_three"></div>
              <div className="object" id="object_four"></div>
              <div className="object" id="object_five"></div>
            </div>
          </div>
        </div>
      )}

      <Navbar bg="light" color="#0183F1" expand="lg">
        <Container>
          <Navbar.Brand href="/">GI-board</Navbar.Brand>
          <Navbar.Toggle aria-controls="basic-navbar-nav" />
          <Navbar.Collapse id="basic-navbar-nav">
            <Nav className="ml-auto">
              <NavDropdown title="خانه" id="basic-nav-dropdown">
                <NavDropdown.Item href="/page/assistantplan">
                  برنامه دوره دستیاری
                </NavDropdown.Item>
                <NavDropdown.Item href="/page/educationcenter">
                  مراکز تربیت دستیار
                </NavDropdown.Item>
              </NavDropdown>

              <NavDropdown title="آموزش" id="basic-nav-dropdown">
                <NavDropdown.Item href="/educationslides">
                  اسلاید های اموزشی
                </NavDropdown.Item>
                <NavDropdown.Item href="/educationpodcasts">
                  پادکست های اموزشی
                </NavDropdown.Item>
              </NavDropdown>
              <NavDropdown title="نمونه سوالات" id="basic-nav-dropdown">
                <NavDropdown.Item href="/questionsexample2">
                  سوالات پذیرش دستیار فوق تخصص
                </NavDropdown.Item>
                <NavDropdown.Item href="/questionsexample">
                  سوالات آزمون دانشنامه
                </NavDropdown.Item>
                <NavDropdown.Item href="/page/verbalexam">
                  آشنایی با روش های ازمون شفاهی
                </NavDropdown.Item>
                <NavDropdown.Item href="/page/examsource">
                  منابع آزمون دانشنامه سال جاری
                </NavDropdown.Item>
              </NavDropdown>
              <Nav.Link href="/members">معرفی اعضای هیات ممتحنه</Nav.Link>
              <Nav.Link href="/page/about">درباره ما</Nav.Link>

              <Nav.Link href="/contactus">تماس با ما</Nav.Link>

              {controller.authenticated && controller.userRole === "admin" && (
                <Nav.Link href="/users">لیست کاربران</Nav.Link>
              )}
            </Nav>
          </Navbar.Collapse>
          <Nav.Item>
            <Button
              onClick={() => {
                if (controller.authenticated) {
                  setLogout(dispatch, "");
                } else {
                  setStartLogin(dispatch, !controller.startLogin);
                }
              }}
            >
              {loginText}
            </Button>
          </Nav.Item>
        </Container>
      </Navbar>
    </>
  );
}
