import Link from "next/link";
import Image from "next/image";
import axios from "axios";
import { useEffect, useState } from "react";
import {
  successMessage,
  errorMessage,
  dataErrorsMessage,
  catchMessage,
  successStoreMessage,
} from "../utiliz/showMessage";

const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

export default function Podcasts() {
  const [name, setName] = useState();
  const [rowNumber, setRowNumber] = useState(0);
  const [description, setDiscription] = useState();
  const [fileName, setFileName] = useState();

  const clearForm = () => {
    try {
      setName("");
      setRowNumber(0);
      setDiscription("");
      setFileName("");
      //   setReload(new Date());
    } catch (error) {
      throw error;
    }
  };

  const fileChangeHandler = (e) => {
    setFileName(e.target.files[0]);
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        name: Joi.string().required().min(3).max(256).messages({
          "string.min": `"عنوان پادکست" حداقل {#limit} حرف وارد شود  `,
          "string.max": `"عوان پادکست" حداکثر {#limit} حرف وارد شود  `,
          "any.required": `"عنوان پادکست" وارد شود`,
        }),

        description: Joi.string().required().min(10).max(256).messages({
          "string.min": `" توضیحات  " حداقل{#limit}  حرف وارد شود  `,
          "string.max": `" توضیحات  " حداکثر {#limit} حرف وارد شود  `,
          "any.required": `"   توضیحات" وارد شود`,
        }),
        // fileName: Joi.string().required().messages({
        //   "any.required": `"فایل" انتخاب شود`,
        // }),
      });
      const { error } = schema.validate({
        name: name,
        description: description,
        // fileName: fileName,
      });
      if (error) {
        errorMessage(error.details[0].message);
        // console.log(error)
        return false;
      }
      return true;
    } catch (error) {
      console.log("------------", error);

      setLoading(false);
      catchMessage(error);
      return false;
    }
  };
  const handleSubmitClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("name", name);
      formData.append("fileName", fileName);
      formData.append("description", description);
      formData.append("rowNumber", rowNumber);

      await axios
        .post("/api/podcast/store", formData, {
          headers: {
            "Content-Type": "multipart/formdata",
          },
        })
        .then((result) => {
          console.log("result", result);
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (error) {
      console.log(error);
    }
    successStoreMessage();
    clearForm();
  };
  useEffect(() => {}, []);
  return (
    <div>
      <section className="contact__area grey-bg-13 pt-120 pb-120">
        <div className="container">
          <div className="row">
            <div className="col-xxl-12 col-xl-12 col-lg-12">
              <div className="contact__form contact__form-2 white-bg">
                <h3 className="contact-form-title">ثبت اسلاید اموزشی</h3>
                <form>
                  <div className="row">
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>عنوان اسلاید</label>
                        <input
                          type="text"
                          value={name}
                          onChange={(e) => {
                            setName(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className=" contact__input contact__input-2 mb-30">
                        <label>ردیف</label>
                        <input
                          name="file"
                          id="filer_input2"
                          type="number"
                          value={rowNumber}
                          onChange={(e) => {
                            setRowNumber(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>توضیحات کوتاه</label>
                        <textarea
                          id="w3review"
                          name="w3review"
                          rows="4"
                          cols="50"
                          value={description}
                          onChange={(e) => {
                            setDiscription(e.target.value);
                          }}
                        />
                      </div>
                    </div>
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className=" contact__input contact__input-2 mb-30">
                        <label>برای اپلود فایل خود اینجا کلیک کنید</label>
                        <input
                          
                          name="file"
                          id="filer_input2"
                          type="file"
                          onChange={fileChangeHandler}
                        />
                      </div>
                    </div>

                    <div className="col-xl-12">
                      <div className="contact__form-btn-2">
                        <button
                          style={{ float: "left" }}
                          type="button"
                          onClick={() => {
                            handleSubmitClick();
                          }}
                        >
                          <span className="d-flex align-items-center">ثبت</span>
                        </button>
                      </div>
                    </div>
                  </div>
                </form>
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  );
}
