import Link from "next/link";
import axios from "axios";
import { useEffect, useState } from "react";
import Paper from "@mui/material/Paper";
import Table from "@mui/material/Table";
import { Grid, TableHead, colors } from "@mui/material";
import TableRow from "@mui/material/TableRow";
import TableBody from "@mui/material/TableBody";
import TableCell from "@mui/material/TableCell";
import TableContainer from "@mui/material/TableContainer";
import Dialog from "@mui/material/Dialog";
import DialogContent from "@mui/material/DialogContent";
import CloseIcon from "@mui/icons-material/Close";
import IconButton from "@mui/material/IconButton";
import DeleteIcon from "@mui/icons-material/Delete";

import {
  successStoreMessage,
  errorMessage,
  catchMessage,
  deleteAlert,
  successDeleteMessage,
} from "../../utiliz/showMessage";
import { setLoading, useLiTechController } from "@/utils/context";
import StoreMessage from "./storeMessages";
import DisplayMessage from "./displayMessage";

export default function ContactUs(props) {
  const [controller, dispatch] = useLiTechController();
  const [messages, setMessages] = useState();
  const [open, setOpen] = useState(false);
  const [showMessage, setShowMessage] = useState([]);
  const [mode, setMode] = useState();

  const handleOpen = () => setOpen(true);
  const handleClose = () => {
    setOpen(false);
  };

  const getMessages = async () => {
    try {
      setLoading(dispatch, true);
      await axios.get(`/api/contact/get`).then((result) => {
        setLoading(dispatch, false);
        setMessages(result.data.data);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  const messageReaded = async (id) => {
    console.log("idddddddd", id);
    try {
      await axios
        .post(`/api/contact/read`, { id })

        .then((result) => {
          console.log("result", result);
          getMessages();
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (err) {
      console.log(err);
    }
  };

  const deleteMessage = async (id) => {
    console.log("idid", id);
    try {
      if (await deleteAlert()) {
        await axios
          .post(`/api/contact/delete`, { id })

          .then((result) => {
            console.log("result", result);

            successDeleteMessage();

            getMessages();
          })
          .catch((err) => {
            console.log(err);
          });
      }
    } catch (err) {
      console.log(err);
    }
  };
  useEffect(() => {
    if (controller.authenticated && controller.userRole === "admin") {
     setMode(<DisplayMessage />)
    }else{
      setMode(<StoreMessage />)
    }
  }, [controller.authenticated]);
  return (
    <div>
      <main>
        <section className="page__title-area pt-55   p-relative page__title-overlay aboutback">
          <div className="container">
            <div className="row">
              <div className="col-xxl-12">
                <div className="page__title-wrapper">
                  <h3 className="page__title">تماس با ما</h3>

                  <nav aria-label="breadcrumb">
                    <ol className="breadcrumb">
                      <li className="breadcrumb-item">
                        <Link href="/"> خانه </Link>
                      </li>
                      <li
                        className="breadcrumb-item active"
                        aria-current="page"
                      >
                        تماس با ما
                      </li>
                    </ol>
                  </nav>
                </div>
              </div>
            </div>
          </div>
        </section>
         {mode}
  
       
      </main>
    </div>
  );
}
