import axios from "axios";
import Box from "@mui/material/Box";
import MenuItem from "@mui/material/MenuItem";
import FormControl from "@mui/material/FormControl";
import Select from "@mui/material/Select";
import { useEffect, useState } from "react";
import Dialog from "@mui/material/Dialog";
import DialogContent from "@mui/material/DialogContent";
import DialogTitle from "@mui/material/DialogTitle";
import CloseIcon from "@mui/icons-material/Close";
import IconButton from "@mui/material/IconButton";
import {
  successStoreMessage,
  errorMessage,
  catchMessage,
  sendMessageAlert,
} from "../../utiliz/showMessage";
import {
  setLoading,
  setStartLogin,
  useLiTechController,
} from "@/utils/context";
import LoginComponent from "@/components/login";
const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

export default function StoreMessage(props) {
  const [controller, dispatch] = useLiTechController();
  const [name, setName] = useState();
  const [email, setEmail] = useState();
  const [phone, setPhone] = useState();
  const [message, setMessage] = useState();
  const [section, setSection] = useState("");
  const [openLogin, setOpenLogin] = useState(false);

  const handleOpenLogin = () => setOpenLogin(true);
  const handleCloseLogin = () => {
    setOpenLogin(false);
  };
  const clearForm = () => {
    try {
      setName("");
      setEmail("");
      setPhone("");
      setMessage("");
      setSection();
    } catch (error) {
      throw error;
    }
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        // section: Joi.string().required().messages({
        //   "any.required": ` لطفابخش مرتبط خود انتخاب کنید`,
        //   "string.empty": ` لطفا بخش مرتبط خود انتخاب کنید`,
        // }),
        name: Joi.string().required().messages({
          "any.required": ` لطفا نام و نام خانوادگی خود وارد کنید`,
          "string.empty": ` لطفا نام و نام خانوادگی خود وارد کنید`,
        }),

        email: Joi.string().required().messages({
          "any.required": ` ایمیل خود را وارد کنید`,
          "string.empty": ` ایمیل خود را وارد کنید`,
        }),

        phone: Joi.string().required().messages({
          "any.required": `  شماره تماس خود را وارد کنید`,
          "string.empty": `  شماره تماس خود را وارد کنید`,
        }),

        message: Joi.string().required().messages({
          "any.required": `  پیام خود را وارد کنید`,
          "string.empty": ` پیام خود را وارد کنید`,
        }),
      });
      const { error } = schema.validate({
        // section : section,
        name: name,
        email: email,
        phone: phone,
        message: message,
      });
      if (error) {
        errorMessage(error.details[0].message);
        return false;
      }

      return true;
    } catch (error) {
      console.log("------------", error);

      setLoading(false);
      catchMessage(error);
      return false;
    }
  };

  const postContac = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const data = {
        name,
        email,
        phone,
        message,
        section,
      };
      setLoading(dispatch, true);
      console.log("dispatch", dispatch);

      await axios
        .post("/api/contact/contact/", data)

        .then((result) => {
          console.log("result", result);
          setLoading(dispatch, false);
          clearForm();
          successStoreMessage();
          getMessages();
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (err) {
      console.log(err);
    }
  };

  const login = async (id) => {
    console.log("idid", id);
    try {
      if (!controller.authenticated) {
        if (await sendMessageAlert()) {
          handleOpenLogin();
        }
      
      } 
       setStartLogin(dispatch, false);
    } catch (err) {
      console.log(err);
    }
  };

  return (
    <section className="contact__area grey-bg-13 pt-120 pb-120">
      <div className="container">
        <div className="row">
          <div className="col-xxl-12 col-xl-12 col-lg-12">
            <div className="contact__form contact__form-2 white-bg">
              <h3 className="contact-form-title">در تماس باشید</h3>
              <form>
                <div className="row">
                  <div
                    className="col-xxl-6 col-xl-6 col-lg-6 col-md-6"
                    style={{ display: "none" }}
                  >
                    <div className="contact__input contact__input-2 mb-30">
                      <Box sx={{ minWidth: 120 }}>
                        <label> بخش مربوطه*</label>
                        <FormControl fullWidth>
                          <Select
                            labelId="demo-simple-select-label"
                            id="demo-simple-select"
                            value={section}
                            label="بخش مربوطه"
                            onChange={(e) => {
                              setSection(e.target.value);
                            }}
                          >
                            <MenuItem value={"بخش یک"}>بخش 1</MenuItem>
                            <MenuItem value={"بخش دو"}>بخش 2</MenuItem>
                            <MenuItem value={"بخش سه"}>بخش 3</MenuItem>
                          </Select>
                        </FormControl>
                      </Box>
                    </div>
                  </div>
                  <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                    <div className="contact__input contact__input-2 mb-30">
                      <label>نام ونام خانوادگی*</label>
                      <input
                        type="text"
                        value={name}
                        onChange={(e) => {
                          setName(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                    <div className="contact__input contact__input-2 mb-30">
                      <label>پست الکترونیک</label>
                      <input
                        type="email"
                        pattern="[^ @]*@[^ @]*"
                        value={email}
                        onChange={(e) => {
                          setEmail(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                    <div className="contact__input contact__input-2 mb-30">
                      <label>شماره تماس*</label>
                      <input
                        type="tel"
                        value={phone}
                        onChange={(e) => {
                          setPhone(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6"></div>
                  <div className="contact__input contact__input-2 mb-30">
                    <label> متن پیام*</label>
                    <textarea
                      value={message}
                      onChange={(e) => {
                        setMessage(e.target.value);
                      }}
                    />
                  </div>
                  {controller.authenticated ? (
                    <div className="col-xl-12">
                      <div className="contact__form-btn-2">
                        <button
                          style={{ float: "left" }}
                          type="button"
                          onClick={() => {
                            postContac();
                          }}
                        >
                          <span className="d-flex align-items-center">
                            ارسال <i className="flaticon-paper-plane"></i>
                          </span>
                        </button>
                      </div>
                    </div>
                  ) : (
                    <div className="col-xl-12">
                      <div className="contact__form-btn-2">
                        <button
                          style={{ float: "left" }}
                          type="button"
                          onClick={() => {
                            login();
                          }}
                        >
                          <span className="d-flex align-items-center">
                            ارسال <i className="flaticon-paper-plane"></i>
                          </span>
                        </button>
                      </div>
                    </div>
                  )}
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
      <Dialog
        open={openLogin}
        onClose={() => {
          setStartLogin(dispatch, false);
        }}
        aria-labelledby="alert-dialog-title"
        aria-describedby="alert-dialog-description"
      >
        <IconButton
          color="inherit"
          onClick={handleCloseLogin}
          aria-label="close"
        >
          <CloseIcon />
        </IconButton>
        <DialogTitle id="alert-dialog-title">
          <h3 className="contact-form-title">ورود به حساب کاربری</h3>
        </DialogTitle>
        <DialogContent>
          <LoginComponent handleCloseLogin={handleCloseLogin} />
        </DialogContent>
      </Dialog>
    </section>
  );
}
