import axios from "axios";
import Link from "next/link";
import { useState, useEffect } from "react";
import AddIcon from "@mui/icons-material/Add";
import EditIcon from "@mui/icons-material/Edit";
import Dialog from "@mui/material/Dialog";
import DialogContent from "@mui/material/DialogContent";
import DialogTitle from "@mui/material/DialogTitle";
import HelpOutlineIcon from "@mui/icons-material/HelpOutline";
import CloseIcon from "@mui/icons-material/Close";
import IconButton from "@mui/material/IconButton";
import Slides from "./slides";

import DeleteIcon from "@mui/icons-material/Delete";
import {
  setLoading,
  useLiTechController,
  setStartLogin,
} from "@/utils/context";

import {
  successStoreMessage,
  errorMessage,
  catchMessage,
  deleteAlert,
  successDeleteMessage,
  loginAlert,
  activeLogin,
} from "../../utiliz/showMessage";
import config from "@/utils/config";
import Swal from "sweetalert2";
import LoginComponent from "@/components/login";
export default function EducationSlides(props) {
  const [controller, dispatch] = useLiTechController();

  const [open, setOpen] = useState(false);
  const [show, setShow] = useState(false);
  const [openLogin, setOpenLogin] = useState(false);
  const handleShow = () => setShow(true);
  const handleOpen = () => setOpen(true);

  const handleClose = () => {
    setEditId();
    setOpen(false);
    setShow(false);
    setOpenLogin(false);
  };



  const [slides, setSlides] = useState();
  const [editId, setEditId] = useState();
  const [showDes, setShowDes] = useState("");
  const [addNewItem, setAddNewItem] = useState();

  
  const handleOpenLogin = () => setOpenLogin(true);
  const handleCloseLogin = () => {
    setOpenLogin(false);
  };


  const getSlides = async () => {
    try {
      setLoading(dispatch, true);
      await axios.get(`/api/slide/slide`).then((result) => {
        setLoading(dispatch, false);
        setSlides(result.data.data);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  const deleteMessage = async (id) => {
    console.log("idid", id);
    try {
      if (await deleteAlert()) {
        await axios
          .post(`/api/slide/delete`, { id })

          .then((result) => {
            console.log("result", result);

            successDeleteMessage();

            getSlides();
          })
          .catch((err) => {
            console.log(err);
          });
      }
    } catch (err) {
      console.log(err);
    }
  };

  const login = async (id) => {
    console.log("idid", id);
    try {
      if(!controller.authenticated){
         if (await loginAlert()) {
        handleOpenLogin();
      }
      }else if(controller.active !== true){
        activeLogin();
      }

    } catch (err) {
      console.log(err);
    }
  };
  useEffect(() => {
    setAddNewItem(
      controller.authenticated && controller.userRole === "admin" && (
        <AddIcon
          style={{ cursor: "pointer", fontSize: 50 }}
          onClick={handleOpen}
        />
      )
    );

    getSlides();
  }, [controller.authenticated]);

  return (
    <div style={{ overflow: "hidden" }}>
      <section className="page__title-area pt-55   p-relative page__title-overlay sliderback">
        <div className="container">
          <div className="row">
            <div className="col-xxl-12">
              <div className="page__title-wrapper">
                <h3 className="page__title">اسلاید های اموزشی</h3>

                <nav aria-label="breadcrumb">
                  <ol className="breadcrumb">
                    <li className="breadcrumb-item">
                      <Link href="/"> خانه </Link>
                    </li>
                    <li className="breadcrumb-item active" aria-current="page">
                      اسلاید های اموزشی
                    </li>
                  </ol>
                </nav>
              </div>
            </div>
          </div>
        </div>
      </section>
      <section className="about__area  about-orange-color">
        <div className="row">
          <section className="category__area grey-bg-5 pt-110 pb-120">
            <div className="container">
              <div className="row justify-content-center">
                <div className="col-xxl-4 col-xl-6">
                  <div className="section__title-wrapper-7 mb-50 text-center">
                    <h2 className="section__title-7">اسلایدهای آموزشی</h2>
                    {addNewItem}
                  </div>
                </div>
              </div>
              <div className="row">
                {slides?.map((item) => (
                  <div className="col-xxl-3 col-xl-3 col-lg-4 col-md-6">
                    <HelpOutlineIcon
                      style={{
                        cursor: "pointer",
                        fontSize: 30,
                        display: "flex",
                        float: "left",
                        marginRight: -55,
                      }}
                      onClick={() => {
                        setShowDes(item.description);
                        handleShow();
                      }}
                    />
                    {controller.authenticated &&
                      controller.userRole === "admin" && (
                        <div>
                          <EditIcon
                            style={{
                              cursor: "pointer",
                              fontSize: 25,
                              display: "flex",
                              float: "right",
                              marginLeft: -55,
                            }}
                            onClick={() => {
                              setEditId(item._id);
                              handleOpen();
                            }}
                          />

                          <DeleteIcon
                            style={{
                              cursor: "pointer",
                              fontSize: 25,
                              display: "flex",
                              float: "left",
                              marginRight: -55,
                              marginLeft: 30,
                            }}
                            className="button"
                            onClick={() => {
                              deleteMessage(item._id);
                            }}
                          />
                        </div>
                      )}
                    <div className="category__item white-bg transition-3 mb-30 d-flex align-items-center">
                      <div className="category__icon mr-20">
                        <i className="flaticon-improvement"></i>
                      </div>
                      <div
                        className="category__content"
                        style={{ minHeight: 100, overflow: "hidden" }}
                      >
                        <h3 className="category__title">{item.name}</h3>
                      </div>
                    </div>
                    <div className="row">
                      <div
                        className="col-12"
                        style={{
                          textAlign: "left",
                          color: "#000",
                          marginTop: -80,
                          marginRight: -30,
                        }}
                      >
                        {(controller.authenticated && controller.active === true)?(
                          
                          <Link
                            href={`${config.uploadAddress}/upload/slide/${item.fileName}`}
                            target={"_blank"}
                          >
                            دانلود فایل
                          </Link>
                        ) : (
                          <button
                            onClick={() => {
                              login();
                            }}
                          >
                            دانلود فایل
                          </button>
                        )}
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          </section>
        </div>
      </section>
      <Dialog
        open={open}
        onClose={handleClose}
        aria-labelledby="alert-dialog-title"
        aria-describedby="alert-dialog-description"
      >
        <DialogTitle id="alert-dialog-title">
          <h3 className="contact-form-title">
            {editId ? "ویرایش اسلاید اموزشی" : "ثبت اسلاید اموزشی"}
          </h3>
        </DialogTitle>

        <DialogContent>
          <Slides
            id={editId}
            handleClose={handleClose}
            getSlides={getSlides}
            rowDefaultNumber={slides?.length}
          />
        </DialogContent>
      </Dialog>

      <Dialog
        open={show}
        onClose={handleClose}
        aria-describedby="alert-dialog-slide-description"
      >
        <IconButton
          edge="start"
          color="inherit"
          onClick={handleClose}
          aria-label="close"
        >
          <CloseIcon />
        </IconButton>

        <DialogContent style={{ minWidth: 500, minHeight: 350 }}>
          <div
            dangerouslySetInnerHTML={{
              __html: showDes?.replace(/\n/g, "<br/>"),
            }}
          />
        </DialogContent>
      </Dialog>

      <Dialog
        open={openLogin}
        onClose={() => {
          setStartLogin(dispatch, false);
        }}
        aria-labelledby="alert-dialog-title"
        aria-describedby="alert-dialog-description"
      >
        <IconButton color="inherit" onClick={handleClose} aria-label="close">
          <CloseIcon />
        </IconButton>
        <DialogTitle id="alert-dialog-title">
          <h3 className="contact-form-title">ورود به حساب کاربری</h3>
        </DialogTitle>
        <DialogContent>
          <LoginComponent handleCloseLogin={handleCloseLogin} />
        </DialogContent>
      </Dialog>
    </div>
  );
}
