import { useLiTechController } from "@/utils/context";
import { useRouter } from "next/router";
import { useEffect, useState } from "react";
import axios from "axios";
import EditComponent from "./editComponent";
import DisplayComponent from "./displayComponent";
import Image from "next/image";
import Link from "next/link";
import config from "@/utils/config";

export default function Page() {
  const [controller, dispatch] = useLiTechController();

  const router = useRouter();
  const [pageItem, setPageItem] = useState(router.query.name);
  const [data, setData] = useState();

  const getPageData = async (pageNameParam) => {
    try {
      await axios.get(`/api/page/${pageNameParam}`).then((result) => {
        setData(result.data?.data);
        setPageItem(
          controller.authenticated && controller.userRole === "admin" ? (
            <EditComponent
              titleProp={result.data?.data?.title}
              textProp={result.data?.data?.text}
              pageName={router.query.name}
              getPageData={getPageData}
            />
          ) : (
            <DisplayComponent
              title={result.data?.data?.title}
              text={result.data?.data?.text}
              image={result.data?.data?.fileName}
            />
          )
        );
      });
    } catch (err) {
      console.log(err);
    }
  };

  useEffect(() => {
    console.log("routername", router);
    if (!router.isReady) return;
    getPageData(router.query.name);
  }, [router.isReady, router.query.name, controller.authenticated]);

  return (
    <div style={{ minHeight: 400, marginTop: 60 }}>
      <section className="page__title-area mt-55   p-relative page__title-overlay ">
        <Image
          style={{ width: "100%", height: 220 }}
          width={0}
          height={0}
          sizes="100vw"
          src={`${config.uploadAddress}/upload/images/${data?.fileName}`}
          alt=""
        />
        <div
          className="row "
          style={{
            position: "absolute",
            top: 80,
            paddingRight: "10%",
            paddingLeft: "10%",
            lineHeight:80
          }}
        >
          <div className="col-xxl-12">
            <div className="page__title-wrapper">
              <h3 className="page__title">{data?.title}</h3>
            </div>
          </div>
        </div>
      </section>
      {pageItem}
    </div>
  );
}
