import axios from "axios";
import Editor from "@/components/editor";

import { useEffect, useState } from "react";
import { successStoreMessage } from "@/utiliz/showMessage";
import { setLoading, useLiTechController } from "@/utils/context";

export default function EditComponent(props) {
  const [controller, dispatch] = useLiTechController();
  const [editorLoaded, setEditorLoaded] = useState(false);
  const { titleProp, textProp, pageName, getPageData } = props;
  const [title, setTitle] = useState(titleProp);
  const [text, setText] = useState(textProp);
  const [fileName, setFileName] = useState(textProp);

  const clearForm = () => {
    try {
      setTitle("");
      setText("");
      setFileName();
    } catch (error) {
      throw error;
    }
  };
  const fileChangeHandler = (e) => {
    setFileName(e.target.files[0]);
  };
  const handleSubmitClick = async () => {
    try {
      const formData = new FormData();

      formData.append("pageName", pageName);
      formData.append("text", text);
      formData.append("title", title);
      formData.append("fileName", fileName);

      setLoading(dispatch, true);
      await axios
        .post("/api/page/store/", formData)
        .then((result) => {
          setLoading(dispatch, false);
          console.log("result", result);
          clearForm();
          getPageData(pageName);
          setEditorLoaded(true);
          successStoreMessage();
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (error) {
      console.log(error);
    }
  };
  useEffect(() => {
    setEditorLoaded(true);
    if (props.textProp) {
      setTitle(titleProp);
      setText(textProp);
    }
  }, [props.textProp]);
  return (
    <section className="about__area pt-35 pb-130 about-orange-color">
      <div className="container">
        <div className="row">
          <div className="col-xxl-12 col-xl-12 col-lg-12">
            <div className="about__wrapper-4 pt-25">
              <div className="section__title-wrapper mb-30">
                <h2 className="section__title-5">
                  <div className="row">
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className=" contact__input contact__input-2 mb-30">
                        <label>عنوان</label>
                        <input
                          name="title"
                          id="title"
                          type="text"
                          value={title}
                          onChange={(e) => {
                            console.log(e.target.value);
                            setTitle(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className=" contact__input contact__input-2 mb-30 ">
                      <label>برای اپلود تصویر اینجا کلیک کنید</label>
                      <input
                        name="file"
                        id="file"
                        type="file"
                        accept="image/png, image/gif, image/jpeg"
                        onChange={fileChangeHandler}
                      />
                    </div>
                  </div>
                </h2>
              </div>

              <div className=" contact__input contact__input-2 mb-30">
                <label>محتوی</label>
                <Editor
                  name="description"
                  onChange={(data) => {
                    setText(data);
                  }}
                  editorLoaded={editorLoaded}
                  value={text}
                >
                  {text}
                </Editor>
              </div>
              <div className="row">
                <div className="col-xxl-12 col-xl-12 col-lg-12 ">
                  <button
                    type="button"
                    style={{
                      float: "left",
                      padding: "5px 20px",
                      borderRadius: 5,
                      backgroundColor: "#0d6efd",
                      color: "#fff",
                    }}
                    onClick={handleSubmitClick}
                  >
                    ثبت
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}
