import axios from "axios";
import { useEffect, useState } from "react";
import {
  successMessage,
  errorMessage,
  dataErrorsMessage,
  catchMessage,
  successStoreMessage,
  successUpdateMessage,
} from "../../utiliz/showMessage";
import * as React from "react";

import { setLoading, useLiTechController } from "@/utils/context";
const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

export default function Questions(props) {
  const [controller, dispatch] = useLiTechController();
  const [category, setCategory] = useState();
  const [title, setTitle] = useState("");
  const [rowNumber, setRowNumber] = useState(0);
  const [description, setDescription] = useState("");
  const [fileName, setFileName] = useState();
  const [categories, setCategories] = useState();
  const {
    id,
    handleClose,
    getQuestions,
    getQuestionCategorie,
    rowDefaultNumber,
  } = props;

  const clearForm = () => {
    try {
      setTitle("");
      setCategory("");
      setRowNumber(0);
      setDescription("");
      setFileName();
    } catch (error) {
      throw error;
    }
  };

  const fileChangeHandler = (e) => {
    setFileName(e.target.files[0]);
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        category: Joi.string().required().min(3).max(256).messages({
          "string.min": `عنوان گروه حداقل {#limit} حرف وارد شود  `,
          "string.max": `عوان گروه حداکثر {#limit} حرف وارد شود  `,
          "any.required": ` عنوان گروه  وارد شود`,
          "string.empty": ` عنوان گروه وارد شود`,
        }),
        title: Joi.string().required().min(3).max(256).messages({
          "string.min": `عنوان فایل حداقل {#limit} حرف وارد شود  `,
          "string.max": `عوان فایل حداکثر {#limit} حرف وارد شود  `,
          "any.required": ` عنوان فایل  وارد شود`,
          "string.empty": ` عنوان فایل وارد شود`,
        }),

        description: Joi.string().required().messages({
          "any.required": ` توضیحات  وارد شود`,
          "string.empty": `توضیحات وارد شود`,
        }),
      });
      const { error } = schema.validate({
        category: category,
        title: title,
        description: description,
      });
      if (error) {
        errorMessage(error.details[0].message);
        return false;
      }

      if (!fileName) {
        errorMessage("لطفا فایل مورد نظر خود را انتخاب کنید");
        return false;
      }
      return true;
    } catch (error) {
      setLoading(false);
      catchMessage(error);
      return false;
    }
  };
  const handleSubmitClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("title", title);
      formData.append("category", category);
      formData.append("fileName", fileName);
      formData.append("description", description);
      formData.append("rowNumber", rowNumber);
      setLoading(dispatch, true);
      await axios
        .post("/api/question2/store", formData, {
          headers: {
            "Content-Type": "multipart/formdata",
          },
        })
        .then((result) => {
          setLoading(dispatch, false);
          console.log("result", result);
          clearForm();
          getQuestions();
          getQuestionCategorie();
          handleClose();
          successStoreMessage();
          handleClose();
     
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (error) {
      console.log(error);
    }
  };

  const getQuestion = () => {
    try {
      axios.post(`/api/question2/getquestion`, { id }).then((result) => {
        console.log("resultresultresult", result.data.data);
        setTitle(result.data.data.title);
        setCategory(result.data.data.category);
        setRowNumber(result.data.data.rowNumber);
        setDescription(result.data.data.description);
        setFileName(result.data.data.fileName);
      });
    } catch (err) {
      console.log(err);
    }
  };

  const handleEditClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("id", id);
      formData.append("title", title);
      formData.append("category", category);
      formData.append("fileName", fileName);
      formData.append("description", description);
      formData.append("rowNumber", rowNumber);
      setLoading(dispatch, true);
      console.log("updatedata", formData);
      axios
        .put("/api/question2/update", formData)
        .then((result) => {
          setLoading(dispatch, true);
          clearForm();
          getQuestionCategorie();
          getQuestions();
          successUpdateMessage();
          handleClose();
        })
        .catch((err) => {
          errorMessage(err.message);
        });
    } catch (err) {
      console.log(err);
    }
  };

  const getQuestionCategories = async () => {
    try {
      await axios.get(`/api/question2/questioncategories`).then((result) => {
        setCategories(result.data.data);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  useEffect(() => {
    console.log("categories", categories);

    setRowNumber(rowDefaultNumber + 1);
    // console.log("----", id);
    if (id) getQuestion();

    getQuestionCategories();
  }, []);
  return (
    <div className="row">
      <div className="col-xxl-12 col-xl-12 col-lg-12">
        <div className="contact__form contact__form-2 white-bg">
          <form>
            <div className="row">
              <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                <div className=" contact__input contact__input-2 mb-30">
                  <label>ردیف</label>
                  <input
                    name="rowNumber"
                    id="rowNumber"
                    type="number"
                    value={`${rowNumber}`}
                    onChange={(e) => {
                      console.log(e.target.value);
                      setRowNumber(e.target.value);
                    }}
                  />
                </div>
              </div>
              <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                <div className="contact__input contact__input-2 mb-30">
                  <label>گروه مربوطه</label>
                  <input
                    name="category"
                    list="categories"
                    id="category"
                    type="category"
                    value={category}
                    onChange={(e) => {
                      console.log(e.target.value);
                      setCategory(e.target.value);
                    }}
                  />
                  <datalist id="categories" fullWidth>
                    {categories?.map((item) => (
                      <option key={item._id} value={item} title={item}>
                        {item}
                      </option>
                    ))}
                  </datalist>
                </div>
              </div>

              <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                <div className="contact__input contact__input-2 mb-30">
                  <label>عنوان فایل</label>
                  <input
                    name="title"
                    id="title"
                    type="text"
                    value={title}
                    onChange={(e) => {
                      console.log(e.target.value);
                      setTitle(e.target.value);
                    }}
                  />
                </div>
              </div>
              <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                <div className=" contact__input contact__input-2 mb-30 ">
                  <label> اپلود فایل</label>
                  <input
                    name="file"
                    id="file"
                    type="file"
                    // accept="application/msword, application/vnd.ms-excel, application/vnd.ms-powerpoint"
                    onChange={fileChangeHandler}
                  />
                </div>
              </div>
              <div className=" col-md-12">
                <div className="contact__input contact__input-2 mb-30">
                  <label>توضیحات کوتاه</label>
                  <textarea
                    id="description"
                    name="description"
                    rows="4"
                    cols="50"
                    value={description}
                    onChange={(e) => {
                      setDescription(e.target.value);
                    }}
                  />
                </div>
              </div>
              <div className="col-xl-12">
                <div className="contact__form-btn-2">
                  <button
                    style={{ float: "left" }}
                    type="button"
                    onClick={() => {
                      id ? handleEditClick() : handleSubmitClick();
                    }}
                  >
                    {id ? "ویرایش" : "ثبت"}
                  </button>
                </div>
              </div>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}
