// ** React Imports
import { useState, Fragment } from "react";
import axios from "axios";
// ** Next Imports
import Link from "next/link";

// ** MUI Components

import * as React from "react";

// // ** Icons Imports
// import Google from 'mdi-material-ui/Google';
// import Github from 'mdi-material-ui/Github';
// import Twitter from 'mdi-material-ui/Twitter';
// import Facebook from 'mdi-material-ui/Facebook';
// import EyeOutline from 'mdi-material-ui/EyeOutline';
// import EyeOffOutline from 'mdi-material-ui/EyeOffOutline';

// // ** Configs
// import themeConfig from 'src/configs/themeConfig';

// // ** Layout Import
// import BlankLayout from 'src/@core/layouts/BlankLayout';

// // ** Demo Imports
// import FooterIllustrationsV1 from 'src/views/pages/auth/FooterIllustration';
// import { setLoading, useLiTechController } from 'src/@core/context';
// import { storeUser } from 'src/controller/user';

// import { useRouter } from 'next/router';
// import { useNavigate } from 'react-router-dom';
import { useEffect } from "react";
import {
  successMessage,
  errorMessage,
  dataErrorsMessage,
  successStoreUser,
  catchMessage,
  successStoreMessage,
} from "../../utiliz/showMessage";
import { setLoading, useLiTechController } from "@/utils/context";
import {sendSMSIR} from "../api/sendSms"


const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

const RegisterPage = (props) => {
  const [controller, dispatch] = useLiTechController();
  const [loading, setLoading] = useState(false);
  const [, setReload] = useState(new Date());
  const [name, setName] = useState();
  const [username, setUsername] = useState();
  const [userRole, setUserRole] = useState("customer");
  const [phone, setPhone] = useState();
  const [fileName, setFileName] = useState();
  const [password, setPassword] = useState();
  const [repeatPassword, setRepeatPassword] = useState();

  const [admins, setAdmins] = useState();
  const [university, setUniversity] = useState();
  const [dateOfProficiency, setDateOfProficiency] = useState();
  const [nationalId, setNationalId] = useState();

  const [lang, setLang] = useState();
  const [result, setResult] = useState();
  const [agree, setAgree] = useState(false);
  const { id } = props;
  const { statusChange, loginStatus } = props;
  const [values, setValues] = useState({
    password: "",
    showPassword: false,
  });


  const clearForm = () => {
    try {
      setUsername("");
      setName("");
      setUniversity("");
      setDateOfProficiency("");
      setNationalId("");
      setPhone("");
      setUserRole("");
      setPassword("");
      setRepeatPassword("");
    } catch (error) {
      throw error;
    }
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        name: Joi.string().required().min(3).max(256).messages({
          "string.min": `"  نام و نام خانوادگی" حداقل {#limit} حرف وارد شود  `,
          "string.max": `"نام و نام خانوادگی" حداکثر {#limit} حرف وارد شود  `,
          "any.required": `"نام و نام خانوادگی" وارد شود`,
          "string.empty": `"نام و نام خانوادگی" وارد شود`,
        }),

        phone: Joi.string()
          .length(11)
          .pattern(/^[0-9]+$/)
          .messages({
            "string.empty": `"  شماره تماس استاندارد" وارد شود`,
            "string.pattern": `"شماره تماس" استاندارد  {#limit} وارد شود  `,
            "string.length": `"   شماره تماس " باید   {#limit}عدد وارد شود   `,
          }),

        university: Joi.string().required().messages({
          "any.required": `"دانشگاه محل تحصیل" وارد شود`,
          "string.empty": `"دانشگاه محل تحصیل" وارد شود`,
        }),

        nationalId: Joi.string().required().length(10).messages({
          "string.pattern": `" کد ملی" استاندارد  {#limit} وارد شود  `,
          "string.length": `"  کد ملی " باید   {#limit}عدد وارد شود   `,
          "any.required": `"  کد ملی" وارد شود`,
          "string.empty": `"  کد ملی " وارد شود`,
        }),

        dateOfProficiency: Joi.string()
          .required()
          .pattern(
            /^[1-4]\d{3}\/((0[1-6]\/((3[0-1])|([1-2][0-9])|(0[1-9])))|((1[0-2]|(0[7-9]))\/(30|([1-2][0-9])|(0[1-9]))))$/
          )
          .messages({
            "any.required": `"   تاریخ شروع دوره فوق تخصصی" وارد شود`,
            "string.pattern.base": `" تاریخ شروع دوره فوق تخصصی" استاندارد وارد شود  `,
            "string.empty": `"   تاریخ شروع دوره فوق تخصصی " وارد شود`,
          }),

        username: Joi.string().required().min(5).max(256).messages({
          "string.min": `" نام کاربری" حداق.required()ل{#limit}  حرف وارد شود  `,
          "string.max": `"نام کاربری" حداکثر {#limit}حرف وارد شود  `,
          "any.required": `"نام کاربری" وارد شود`,
          "string.empty": `"نام کاربری" وارد شود`,
        }),

        password: Joi.string().required().required().min(8).max(256).messages({
          "string.min": `" رمز عبور " حداقل{#limit}  حرف وارد شود  `,
          "string.max": `"رمز عبور " حداکثر {#limit}حرف وارد شود  `,
          "any.required": `"رمز عبور " وارد شود`,
          "string.empty": `"رمز عبور " وارد شود`,
        }),

        repeatPassword: Joi.string().required().required().min(8).max(256).messages({
          "string.min": `" رمز عبور " حداقل{#limit}  حرف وارد شود  `,
          "string.max": `"رمز عبور " حداکثر {#limit}حرف وارد شود  `,
          "any.required": `"تکرار رمزعبور  " وارد شود`,
          "string.empty": `" تکرار رمز عبور " وارد شود`,
        }),
      });
   
      const { error } = schema.validate({
        name: name,
        phone: phone,
        university: university,
        nationalId: nationalId,  
        dateOfProficiency : dateOfProficiency,    
        username: username,
        password: password,
        repeatPassword : repeatPassword,
      });
      if (error) {
        errorMessage(error.details[0].message);

        return false;
      }
     
      if (!fileName) {
        errorMessage("لطفا فایل مورد نظر خود را انتخاب کنید");
        return false;
      }
      if (repeatPassword!== password) {
        errorMessage("تکرار رمز عبور صحیح نمیباشد");
        return false;
    }
      return true;
    } catch (error) {
      console.log("------------", error);

      setLoading(false);
      catchMessage(error);
      return false;
    }
  };

  const fileChangeHandler = (e) => {
    setFileName(e.target.files[0]);
  };


  const getAdmins = async () => {
    try {
      setLoading(dispatch, true);
      await axios.get(`/api/auth/getadmin`).then((result) => {
        setLoading(dispatch, false);
        setAdmins(result.data.data);
        console.log("admins", result.data.data);
  
          let message = "کاربر جدید"
          result.data.data.map((item)=>{
          sendSMSIR(message , item.phone)
  
          })
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };
  const handleSubmitClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("name", name);
      formData.append("username", username);
      formData.append("userRole", userRole);
      formData.append("phone", phone);
      formData.append("university", university);
      formData.append("dateOfProficiency", dateOfProficiency);
      formData.append("nationalId", nationalId);
      formData.append("fileName", fileName);
      formData.append("password", password);
      await axios
        .post("/api/auth/store", formData)
        .then((result) => {
          console.log("result", result);
          setResult(result.data);
          getAdmins();
          successStoreUser();
          clearForm();
        })
        .catch((err) => {
         errorMessage(err.response.data.message)
          console.log(err);
        });
    } catch (error) {
      console.log(error);
    }
   
  };

  const getData = async () => {
    try {
      console.log("ididididid", id);
      await axios.get(`/api/auth/${id}`).then((result) => {
        console.log(result);
        setName(result.data.name);
      });
    } catch (err) {
      console.log(err);
    }
  };
  // const updateUser = async () => {
  //   let data = {
  //     id,
  //     name,
  //     lastName,
  //     phone,
  //     username,
  //     password,
  //   };

  //   await axios
  //     .put("/api/auth", data)

  //     .catch((err) => {
  //       console.log("err", err);
  //     });

  //   console.log("updatedata", data);
  // };

  useEffect(() => {
    getData();
  }, []);

  return (
    <>
      <section className="contact__area grey-bg-13 pt-120 pb-120">
        <div className="container">
          <div className="row">
            <div className="col-xxl-12 col-xl-12 col-lg-12">
              <div className="contact__form contact__form-2 white-bg">
                <h3 className="contact-form-title">
                  جهت ثبت نام اطلاعات خود را وارد کنید
                </h3>
                <form>
                  <div className="row">
                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>نام و نام خانوادگی</label>
                        <input
                          type="name"
                          name="name"
                          id="name"
                          value={name}
                          onChange={(e) => {
                            setName(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>شماره تماس</label>
                        <input
                          type="text"
                          name="phone"
                          id="phone"
                          value={phone}
                          onChange={(e) => {
                            setPhone(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>دانشگاه محل تحصیل</label>
                        <input
                          type="university"
                          name="university"
                          id="university"
                          value={university}
                          onChange={(e) => {
                            setUniversity(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>کد ملی</label>
                        <input
                          type="text"
                          name="nationalId"
                          id="nationalId"
                          value={nationalId}
                          onChange={(e) => {
                            setNationalId(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>تاریخ شروع دوره فوق تخصصی</label>
                        <input
                          type="text"
                          placeholder={"yyyy/mm/dd"}
                          name="dateOfProficiency"
                          id="dateOfProficiency"
                          value={dateOfProficiency}
                          onChange={(e) => {
                            setDateOfProficiency(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className=" col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className=" contact__input contact__input-2 mb-30 ">
                        <label>برای اپلود عکس خود اینجا کلیک کنید</label>
                        <input
                          name="file"
                          id="file"
                          type="file"
                          onChange={fileChangeHandler}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>نام کاربری</label>
                        <input
                          type="text"
                          name="userName"
                          id="username"
                          value={username}
                          onChange={(e) => {
                            setUsername(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>رمز عبور</label>
                        <input
                          type="password"
                          name="password"
                          id="password"
                          value={password}
                          onChange={(e) => {
                            setPassword(e.target.value);
                          }}
                        />
                      </div>
                    </div>

                    <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                      <div className="contact__input contact__input-2 mb-30">
                        <label>تکرار رمز عبور</label>
                        <input
                          value={repeatPassword}
                          onChange={(e) => {
                            setRepeatPassword(e.target.value);
                          }}
                          type="password"
                          name="password"
                          id="password"
                        />
                      </div>
                    </div>

                    <div className="col-xl-12">
                      <div className="contact__form-btn-2">
                        <button
                          style={{ float: "left" }}
                          type="button"
                          onClick={() => {
                            handleSubmitClick();
                          }}
                        >
                          <span className="d-flex align-items-center">
                            ثبت نام
                          </span>
                        </button>
                      </div>
                    </div>
                  </div>
                </form>
              </div>
            </div>
          </div>
        </div>
      </section>
    </>
  );
};
RegisterPage.getLayout = (page) => <BlankLayout>{page}</BlankLayout>;

export default RegisterPage;
