import Link from "next/link";
import axios from "axios";
import { useEffect, useState } from "react";
import Paper from "@mui/material/Paper";
import Table from "@mui/material/Table";
import { Grid, TableHead, colors } from "@mui/material";
import TableRow from "@mui/material/TableRow";
import TableBody from "@mui/material/TableBody";
import TableCell from "@mui/material/TableCell";
import TableContainer from "@mui/material/TableContainer";
import config from "@/utils/config";
import Checkbox from "@mui/material/Checkbox";

import {
  successStoreMessage,
  errorMessage,
  catchMessage,
  deleteAlert,
  successDeleteMessage,
} from "../../utiliz/showMessage";
import { setLoading, useLiTechController } from "@/utils/context";
import Image from "next/image";
import { useRouter } from "next/router";
import { sendSMSIR } from "../api/sendSms";
export default function DisplayUsers(props) {
  const [controller, dispatch] = useLiTechController();
  const [users, setUsers] = useState();

  const [admins, setAdmins] = useState();
  const [checked, setChecked] = useState();
  const router = useRouter();
  const handleChange = (event) => {
    setChecked(event.target.checked);
  };

  const getUsers = async () => {
    try {
      setLoading(dispatch, true);
      await axios.get(`/api/auth/user`).then((result) => {
        setLoading(dispatch, false);
        setUsers(result.data.data);
        console.log("users", users);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  const activeUser = async (id, phone) => {
    try {
      await axios
        .post(`/api/auth/active`, { id })

        .then((result) => {
          console.log("result", result);

          let message =
            "حساب کاربری شمادر سایت هیات بورد فوق تخصصی بیماری های گوارش و کبد بزرگسالان فعال شد";

          sendSMSIR(message, phone);

          getUsers();
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (err) {
      console.log(err);
    }
  };

  const inactiveUser = async (id ,phone) => {
    try {
      await axios
        .post(`/api/auth/inactive`, { id })

        .then((result) => {
          console.log("result", result);
          let message =
            "حساب کاربری شمادر سایت هیات بورد فوق تخصصی بیماری های گوارش و کبد بزرگسالان غیر فعال شد";
            sendSMSIR(message, phone);
          getUsers();
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (err) {
      console.log(err);
    }
  };

  useEffect(() => {
    if (!controller.authenticated || !controller.userRole === "admin") {
      router.push("/");
      return;
    }else{
      getUsers();
    }
  }, [controller.authenticated && controller.userRole === "admin"]);

  return (
    <main>
      <section className="page__title-area pt-55   p-relative page__title-overlay aboutback">
        <div className="container">
          <div className="row">
            <div className="col-xxl-12">
              <div className="page__title-wrapper">
                <h3 className="page__title">لیست کاربران</h3>

                <nav aria-label="breadcrumb">
                  <ol className="breadcrumb">
                    <li className="breadcrumb-item">
                      <Link href="/"> خانه </Link>
                    </li>
                    <li className="breadcrumb-item active" aria-current="page">
                      لیست کاربران
                    </li>
                  </ol>
                </nav>
              </div>
            </div>
          </div>
        </div>
      </section>
      <section className="contact__area grey-bg-13 pb-120 pt-150">
        <div className="container">
          <div className="row">
            {controller.authenticated && controller.userRole === "admin" && (
              <div className="col-xxl-12 col-xlg-12- col-lg-12">
                <h3 style={{ marginBottom: 20 }}>لیست کاربران</h3>
                <TableContainer component={Paper}>
                  <Table
                    size="large"
                    sx={{ minWidth: 650 }}
                    aria-label="simple table"
                  >
                    <TableHead style={{ textAlign: "center" }}>
                      <TableRow>
                        <TableCell>عکس کاربر</TableCell>
                        <TableCell>نام و نام خانوادگی</TableCell>
                        <TableCell>شماره تماس</TableCell>
                        <TableCell>نام کاربری</TableCell>
                        <TableCell>دانشگاه محل تحصیل</TableCell>
                        <TableCell>کد ملی</TableCell>
                        <TableCell>تاریخ شروع دوره فوق تخصص</TableCell>

                        <TableCell style={{ width: 120 }}>
                          فعال کردن کاربر
                        </TableCell>
                      </TableRow>
                    </TableHead>
                    <TableBody>
                      {users?.map((row) => (
                        <TableRow key={row.name}>
                          <TableCell>
                            <Image
                              src={`${config.uploadAddress}/upload/user/${row.fileName}`}
                              width={50}
                              height={50}
                              alt="عکس کاربر"
                            />
                          </TableCell>
                          <TableCell>{row.name}</TableCell>
                          <TableCell>{row.phone}</TableCell>
                          <TableCell>{row.username}</TableCell>
                          <TableCell>{row.university}</TableCell>
                          <TableCell>{row.nationalId}</TableCell>
                          <TableCell>{row.dateOfProficiency}</TableCell>

                          <TableCell align="center">
                            <Checkbox
                              checked={row.active}
                              onChange={handleChange}
                              onClick={() => {
                                if (!row.active) {
                                  activeUser(row._id, row.phone);
                                } else {
                                  inactiveUser(row._id , row.phone);
                                }
                              }}
                            />
                          </TableCell>
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                </TableContainer>
              </div>
            )}
          </div>
        </div>
      </section>
    </main>
  );
}
